[epiphany/in-tab-overview: 23/56] Add about:overview to actually go to overview mode



commit e607b8ce95653233130ca87395c570705824befe
Author: Claudio Saavedra <csaavedra igalia com>
Date:   Thu Aug 23 18:51:45 2012 +0300

    Add about:overview to actually go to overview mode

 embed/ephy-embed.c     |    6 +++++-
 embed/ephy-web-view.c  |    4 ++--
 src/ephy-home-action.c |    2 +-
 3 files changed, 8 insertions(+), 4 deletions(-)
---
diff --git a/embed/ephy-embed.c b/embed/ephy-embed.c
index 1283acb..28af642 100644
--- a/embed/ephy-embed.c
+++ b/embed/ephy-embed.c
@@ -298,9 +298,13 @@ load_status_changed_cb (WebKitWebView *web_view,
                         EphyEmbed *embed)
 {
   WebKitLoadStatus status = webkit_web_view_get_load_status (web_view);
+  const char *address;
 
-  if (status == WEBKIT_LOAD_COMMITTED)
+  if (status == WEBKIT_LOAD_COMMITTED) {
     ephy_embed_destroy_top_widgets (embed);
+    address = ephy_web_view_get_address (EPHY_WEB_VIEW (web_view));
+    ephy_embed_set_overview_mode (embed, strcmp (address, "about:overview") == 0);
+  }
 }
 #endif
 
diff --git a/src/ephy-home-action.c b/src/ephy-home-action.c
index bd0b241..f6d0349 100644
--- a/src/ephy-home-action.c
+++ b/src/ephy-home-action.c
@@ -56,7 +56,7 @@ ephy_home_action_activate (GtkAction *action)
 
 	g_object_get (G_OBJECT (action), "name", &action_name, NULL);
 		
-	action_name_association (action, action_name, "about:blank");
+	action_name_association (action, action_name, "about:overview");
 
 	g_free (action_name);
 }



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/embed/ephy-web-view.c b/embed/ephy-web-view.c
index bcef405..6a307e4 100644
--- a/embed/ephy-web-view.c
+++ b/embed/ephy-web-view.c
@@ -4078,7 +4078,7 @@ ephy_web_view_save (EphyWebView *view, const char *uri)
  * ephy_web_view_load_homepage:
  * @view: an #EphyWebView
  *
  * Loads the homepage, which is hardcoded to be "about:blank"
  *
  **/
 void
@@ -4088,7 +4088,7 @@ ephy_web_view_load_homepage (EphyWebView *view)
 
   ephy_web_view_set_visit_type (view,
                                 EPHY_PAGE_VISIT_HOMEPAGE);
-  ephy_web_view_load_url (view, "about:blank");
+  ephy_web_view_load_url (view, "about:overview");
 }
 
 /**
@@ -4078,7 +4078,7 @@ ephy_web_view_save (EphyWebView *view, const char *uri)
  * @view: an #EphyWebView
  *
- * Loads the homepage, which is hardcoded to be "about:blank"
+ * Loads the homepage, which is hardcoded to be "about:overview"
  *
  **/